pub struct CachedDbAccess<TKey, TData, S = RandomState>{ /* private fields */ }Expand description
A concurrent DB store access with typed caching.
Implementations
Sourceimpl<TKey, TData, S> CachedDbAccess<TKey, TData, S>
impl<TKey, TData, S> CachedDbAccess<TKey, TData, S>
pub fn new(db: Arc<DB>, cache_policy: CachePolicy, prefix: Vec<u8>) -> Self
pub fn read_from_cache(&self, key: TKey) -> Option<TData>
pub fn has(&self, key: TKey) -> Result<bool, StoreError>
pub fn read(&self, key: TKey) -> Result<TData, StoreError>
pub fn iterator( &self, ) -> impl Iterator<Item = Result<(Box<[u8]>, TData), Box<dyn Error>>> + '_
pub fn write( &self, writer: impl DbWriter, key: TKey, data: TData, ) -> Result<(), StoreError>
pub fn write_many( &self, writer: impl DbWriter, iter: &mut (impl Iterator<Item = (TKey, TData)> + Clone), ) -> Result<(), StoreError>
Sourcepub fn write_many_without_cache(
&self,
writer: impl DbWriter,
iter: &mut impl Iterator<Item = (TKey, TData)>,
) -> Result<(), StoreError>
pub fn write_many_without_cache( &self, writer: impl DbWriter, iter: &mut impl Iterator<Item = (TKey, TData)>, ) -> Result<(), StoreError>
Write directly from an iterator and do not cache any data. NOTE: this action also clears the cache
pub fn delete(&self, writer: impl DbWriter, key: TKey) -> Result<(), StoreError>
pub fn delete_many( &self, writer: impl DbWriter, key_iter: &mut (impl Iterator<Item = TKey> + Clone), ) -> Result<(), StoreError>
Sourcepub fn delete_all(&self, writer: impl DbWriter) -> Result<(), StoreError>
pub fn delete_all(&self, writer: impl DbWriter) -> Result<(), StoreError>
Deletes all entries in the store using the underlying rocksdb delete_range operation
Sourcepub fn seek_iterator(
&self,
bucket: Option<&[u8]>,
seek_from: Option<TKey>,
limit: usize,
skip_first: bool,
) -> impl Iterator<Item = Result<(Box<[u8]>, TData), Box<dyn Error>>> + '_
pub fn seek_iterator( &self, bucket: Option<&[u8]>, seek_from: Option<TKey>, limit: usize, skip_first: bool, ) -> impl Iterator<Item = Result<(Box<[u8]>, TData), Box<dyn Error>>> + '_
A dynamic iterator that can iterate through a specific prefix / bucket, or from a certain start point.
pub fn prefix(&self) -> &[u8] ⓘ