pub trait StoreResultEmptyTuple {
// Required method
fn unwrap_or_exists(self);
}Required Methods
Sourcefn unwrap_or_exists(self)
fn unwrap_or_exists(self)
Unwrap or assert that the error is key already exists
pub trait StoreResultEmptyTuple {
// Required method
fn unwrap_or_exists(self);
}Unwrap or assert that the error is key already exists